Template Inventory
==================

This workspace contains files relevant to provisioning templated layouts and topologies

libvirt-template-inventory
==========================
Provisions two new libvirt vms

aws-template-inventory
======================
Provisions a new aws ec2 image
